function fnResetParmDefault()
clc;

%% The simulation is run for several combinations of parameters
% The parameters we change are 
% Frequency, length of line, #of Turbines , Wind speed start(and end)
newNumTurbines = 6; % Orig = 6
newFreq = 60;       % Orig = 60 hz
newLineLen = 10;    % Orig = 10 km
newWindSpeedStart = 8;

%% Model name
mdl = 'power_wind_dfig';
% load_system(mdl)


%% BlockPaths 
% This is helpful to index names which have Carriage returns
BlockPaths = find_system(mdl,'Type','Block');

%% To see the actual name of the parameter 
%p = get_param(char(BlockPaths(i)),'DialogParameters');


%% Changing the Line length
% Vary Length of this block
set_param('power_wind_dfig/10 km line','Length', num2str(newLineLen));

%% Changing number of Turbines and Freq
% Use Blockpaths to get 'Wind Turbine Doubly-Fed Induction Generator (Phasor Type)1'
% [6*1.5e6/0.9 575 60] - This has Power, L-LVolts and Freq

windDFIG_NOM = get_param(char(BlockPaths(93)),'nom');
windDFIG_NOM = strrep(windDFIG_NOM,'[','');
tmp = strsplit(windDFIG_NOM);
windDFIG_NOM_MOD = strcat('[', num2str(newNumTurbines), '*1.5e6/0.9', {' '},  tmp(2), {' '}, num2str(newFreq), ']');
set_param(char(BlockPaths(93)),'nom', char(windDFIG_NOM_MOD));

%% Changing wind speed
    % startingSpeed is the passed paramenter
    % Ending speed add 6 to the starting
    % Use Blockpaths to get 'power_wind_dfig/Wind Speed (m//s)'
    %windDlgParms = get_param(char(BlockPaths(91)),'DialogParameters');
    set_param(char(BlockPaths(91)), 'Before',  num2str(newWindSpeedStart));
    set_param(char(BlockPaths(91)), 'After',  num2str(newWindSpeedStart+6));

%% Freq change for these blocks 
    % For the Phasor one
    set_param('power_wind_dfig/powergui', 'frequency', num2str(newFreq));
   
    % For the 120KV source
    posSeq_120 = get_param('power_wind_dfig/120 kV','PositiveSequence'); % contains Amplitude phase and Freq [120e3 0 60]
    posSeq_120 = strrep(posSeq_120,'[','');
    tmp = strsplit(posSeq_120); %we keep the first two parts and mod the Freq 
    posSeq_120_MOD = strcat('[', tmp(1), {' '},  tmp(2), {' '}, num2str(newFreq), ']');
    set_param('power_wind_dfig/120 kV','PositiveSequence', char(posSeq_120_MOD));
    
    % for the 120kv/25kv 47 mva transformer this is BlockPath(3)
    nomPower_47 = get_param(char(BlockPaths(3)),'NominalPower'); % contains MVA and Freq [[47e6 60 ]
    nomPower_47 = strrep(nomPower_47,'[','');
    tmp = strsplit(nomPower_47); %we keep the first two parts and mod the Freq 
    nomPower_47_MOD = strcat('[', tmp(1), {' '},  num2str(newFreq), ']');
    set_param(char(BlockPaths(3)),'NominalPower',char(nomPower_47_MOD));
    
    % Freq in 20km line
    set_param('power_wind_dfig/20 km line','Frequency',num2str(newFreq));
    
    % Freq in 10km line 
    set_param('power_wind_dfig/10 km line','Frequency',num2str(newFreq));
    
    % for the 25kv/575V 6*2mva transformer this is BlockPath(5)
    nomPower_12 = get_param(char(BlockPaths(5)),'NominalPower'); % contains MVA and Freq
    nomPower_12 = strrep(nomPower_12,'[','');
    tmp = strsplit(nomPower_12); %we keep the first two parts and mod the Freq 
    nomPower_12_MOD = strcat('[', tmp(1), {' '},  num2str(newFreq), ']');
    set_param(char(BlockPaths(5)),'NominalPower',char(nomPower_12_MOD));

end

