% ------------------------------------------------------------------------
%  This function is called by fnRunModel.m
%  This runs the simulation and produces the plots in the Scopes defined in
%  the Simulink model
% Input:
%  mdl: The Simulink model
%  cs : The configuration set used by Simulink while running the simulation
%  newNumTurbines: Number of Turbines - affects one block in the model
%  newFreq: Frequency, affects several blocks in the model
%  newLineLen: Line length , affects one block in the model
%  newWindSpeedStart: Starting wind speed , affects one block in the model
% 
% Output:
%   saveObjStruct: this saves gridData,turbineData, gridTitles,
%                  turbineTitles, and all the inputs 
%
%  Author: Meena Ganesh
% ------------------------------------------------------------------------


function [ saveObjStruct ] = fnRunThisSetofParams( mdl,cs,newNumTurbines,newFreq, newLineLen,newWindSpeedStart )
        % http://www.mathworks.com/help/simulink/ug/saving-and-restoring-the-simulation-state-as-the-simstate.html

        %% Modify the params
        fnModifyParms(mdl,newNumTurbines,newFreq, newLineLen,newWindSpeedStart);

        %% Run the model
        model_cs = cs.copy;
%         set_param(mdl,'LoadInitialState','on');       
        % Don't save the Final state;
        %set_param(mdl,'SaveFinalState','off');
        simout = sim(mdl,model_cs);

        sigsOut = get(simout,'sigsOut');
        
        %% Save the Data 
        % Note sigOut is saved by the models and is in the workspace
        [ gridData,turbineData, gridTitles, turbineTitles ] = fnSaveScopeData( sigsOut );

        saveObjStruct.freq = newFreq;
        saveObjStruct.lineLen = newLineLen;
        saveObjStruct.numTurbines = newNumTurbines;
        saveObjStruct.startWindSpeed = newWindSpeedStart;
        saveObjStruct.gridData  = gridData;
        saveObjStruct.turbineData = turbineData;
        saveObjStruct.gridTitles  = gridTitles;
        saveObjStruct.turbineTitles = turbineTitles;
end
