% ------------------------------------------------------------------------
%  This function is called by fnRunThisSetofParams.m
%  Input:
%   Output of the simulation that is obtained by simout = sim(mdl,model_cs);
% 
%  Output:  The Simulink Simulation updates the blocks
%  gridData:  A matrix with 8 columns,  whose rows will vary  
%  turbineData: A matrix with 8 columns,  whose rows will vary  
%  gridTitles:    8 titles for the plots in Data Acq. Scope
%  turbineTitles: 8 titles for the plots in Wind Turbine Scope
%  Author: Meena Ganesh
% ------------------------------------------------------------------------





function [ gridData,turbineData, gridTitles, turbineTitles ] = fnSaveScopeData( sigsOut )
%% Save the data that the Simulation model shows in the Scopes
% Two Scopes exist  1)  Grid Data Acquisition  2) Turbine
    %% Study the Scope 1 outputs
    %  Grid Data Acquisition 
    % Time values are same for all the plots
    gridTitles = {'Vabc_B120 (pu)','Vabc_B25 (pu)','Vabc_B575 (pu)',...
                  'P_B25 (MW)','Q_B25 (Mvar)','V_Plant 2.3kV pos. seq. (pu)', ...
                  'I Plant pos. seq. (pu/2 MVA) ','Motor Speed (pu)'};
                   
    gridData.x_time = sigsOut.get('Vabc_B120 (pu)').Values.Time;
    gridData.x1_data = sigsOut.get('Vabc_B120 (pu)').Values.Data;
    gridData.x2_data = sigsOut.get('Vabc_B25 (pu)').Values.Data;
    gridData.x3_data = sigsOut.get('Vabc_B575 (pu)').Values.Data;
    gridData.x4_data = sigsOut.get('P_B25 (MW)').Values.Data;
    gridData.x5_data = sigsOut.get('Q_B25 (Mvar)').Values.Data;
    gridData.x6_data = sigsOut.get('V_Plant 2.3kV pos. seq. (pu)').Values.Data;
    gridData.x7_data = sigsOut.get('I Plant pos. seq. (pu/2 MVA) ').Values.Data;
    gridData.x8_data = sigsOut.get('Motor Speed (pu)').Values.Data;
 
    %% Study the Scope 2 outputs
    % Wind Turbine
    turbineTitles = {'Pos. seq. V1_B575 (pu)','Pos. seq. I1_B575 (pu)',...
    		'Generated P(MW)','Generated Q(Mvar)','Vdc (V)',...
    		'Speed (pu)','Wind speed (m/s)','pitch angle (deg)'};
    turbineData.w_time  = sigsOut.get('Pos. seq. V1_B575 (pu)').Values.Time;
    turbineData.w1_data = sigsOut.get('Pos. seq. V1_B575 (pu)').Values.Data;
    turbineData.w2_data = sigsOut.get('Pos. seq. I1_B575 (pu)').Values.Data;
    turbineData.w3_data = sigsOut.get('Generated P(MW)').Values.Data;
    turbineData.w4_data = sigsOut.get('Generated Q(Mvar)').Values.Data;
    turbineData.w5_data = sigsOut.get('Vdc (V)').Values.Data;
    turbineData.w6_data = sigsOut.get('Speed (pu)').Values.Data;
    turbineData.w7_data = sigsOut.get('Wind speed (m/s)').Values.Data;
    turbineData.w8_data = sigsOut.get('pitch angle (deg)').Values.Data;

end

